<?php
session_start();

// 获取图片文件夹路径
$imagesDir = 'images';

// 处理排序
$sortBy = $_SESSION['sortBy'] ?? 'time';
if (isset($_GET['sort'])) {
    $sortBy = $_GET['sort'];
    $_SESSION['sortBy'] = $sortBy;
}

// 获取支持的图片文件
$supportedFormats = ['jpg', 'jpeg', 'png', 'bmp', 'gif', 'jfif', 'webp'];
$images = array_filter(scandir($imagesDir), function($file) use ($imagesDir, $supportedFormats) {
    $extension = strtolower(pathinfo($file, PATHINFO_EXTENSION));
    return in_array($extension, $supportedFormats) && is_file("$imagesDir/$file");
});

// 根据排序规则进行排序
usort($images, function($a, $b) use ($sortBy, $imagesDir) {
    if ($sortBy === 'time') {
        return filemtime("$imagesDir/$a") <=> filemtime("$imagesDir/$b");
    }
    return strcmp($a, $b);
});

// 分页设置
$imagesPerPage = 12;
$totalImages = count($images);
$totalPages = ceil($totalImages / $imagesPerPage);
$currentPage = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$start = ($currentPage - 1) * $imagesPerPage;
$imagesToShow = array_slice($images, $start, $imagesPerPage);
?>

<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>图片画廊</title>
    <link rel="stylesheet" href="style.css">
</head>
<body>
    <div class="container">
        <h1>图片画廊</h1>

        <form method="GET" class="sort-form">
            <label for="sort">排序:</label>
            <select name="sort" id="sort" onchange="this.form.submit()">
                <option value="time" <?= $sortBy === 'time' ? 'selected' : '' ?>>按时间排序</option>
                <option value="name" <?= $sortBy === 'name' ? 'selected' : '' ?>>按名称排序</option>
            </select>
        </form>

        <div class="gallery">
            <?php foreach ($imagesToShow as $image): ?>
                <a href="view.php?image=<?= urlencode($image) ?>&sort=<?= $sortBy ?>" target="_blank">
                    <img src="<?= "$imagesDir/$image" ?>" alt="Image">
                </a>
            <?php endforeach; ?>
        </div>

        <div class="pagination">
            <?php if ($currentPage > 1): ?>
                <button><a style="text-decoration:none;color:white" href="?page=<?= $currentPage - 1 ?>&sort=<?= $sortBy ?>" class="pagination-button">上一页</a></button>
            <?php endif; ?>
            <?php if ($currentPage < $totalPages): ?>
                <button><a style="text-decoration:none;color:white" href="?page=<?= $currentPage + 1 ?>&sort=<?= $sortBy ?>" class="pagination-button">下一页</a></button>
            <?php endif; ?>
        </div>
    </div>
</body>
</html>
