<?php
session_start();
$image = $_GET['image'] ?? '';
$sortBy = $_GET['sort'] ?? 'time';
$imagesDir = 'images';

if (!is_file("$imagesDir/$image")) {
    die('图片不存在。');
}

// 获取支持的图片文件
$supportedFormats = ['jpg', 'jpeg', 'png', 'bmp', 'gif', 'jfif', 'webp'];
$allImages = array_filter(scandir($imagesDir), function($file) use ($imagesDir, $supportedFormats) {
    $extension = strtolower(pathinfo($file, PATHINFO_EXTENSION));
    return in_array($extension, $supportedFormats) && is_file("$imagesDir/$file");
});

// 根据排序规则排序
usort($allImages, function($a, $b) use ($sortBy, $imagesDir) {
    if ($sortBy === 'time') {
        return filemtime("$imagesDir/$a") <=> filemtime("$imagesDir/$b");
    }
    return strcmp($a, $b);
});

// 获取当前图片的索引
$currentIndex = array_search($image, $allImages);
$prevImage = $currentIndex > 0 ? $allImages[$currentIndex - 1] : null;
$nextImage = $currentIndex < count($allImages) - 1 ? $allImages[$currentIndex + 1] : null;
?>

<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>图片播放</title>
    <link rel="stylesheet" href="style.css">
    <script>
        let intervalId;
        let playSpeed = localStorage.getItem('playSpeed') || 10; // 默认播放速度10秒
        let images = <?= json_encode($allImages) ?>;
        let currentIndex = <?= $currentIndex ?>;

        function startSlideshow() {
            nextImage();
            intervalId = setInterval(nextImage, playSpeed * 1000);
        }

        function stopSlideshow() {
            clearInterval(intervalId);
        }

        function nextImage() {
            if (currentIndex < images.length - 1) {
                currentIndex++;
                updateImage();
            } else {
                alert("已经是最后一张图片。");
                stopSlideshow();
            }
        }

        function prevImage() {
            if (currentIndex > 0) {
                currentIndex--;
                updateImage();
            }
        }

        function updateImage() {
            const imgElement = document.getElementById('currentImage');
            imgElement.src = "images/" + images[currentIndex];
            document.getElementById('imageTitle').innerText = images[currentIndex];
        }

        function updatePlaySpeed() {
            const newSpeed = prompt("请输入播放时长（秒）:", playSpeed);
            if (newSpeed) {
                playSpeed = newSpeed;
                localStorage.setItem('playSpeed', playSpeed);
            }
        }

        // 触摸事件监听
        let touchstartY = 0;
        let touchendY = 0;
        const threshold = 100; // 设置滑动阈值

        function checkSwipe() {
            const diffY = touchendY - touchstartY;
            if (Math.abs(diffY) > threshold) {
                if (diffY < 0) {
                    nextImage();
                } else {
                    prevImage();
                }
            }
        }

        document.addEventListener('touchstart', e => {
            touchstartY = e.changedTouches[0].screenY;
        });

        document.addEventListener('touchend', e => {
            touchendY = e.changedTouches[0].screenY;
            checkSwipe();
        });
    </script>
</head>
<body>
    <div class="container">
        <a href="index.php" class="back-link">返回图片列表</a>
        <h1 id="imageTitle"><?= $image ?></h1>
        <div class="image-container">
            <img id="currentImage" src="<?= "$imagesDir/$image" ?>" alt="Image" style="max-width: 100%;">
        </div>
        <div class="navigation">
            <?php if ($prevImage): ?>
                <button onclick="prevImage()">上一张</button>
            <?php endif; ?>
            <?php if ($nextImage): ?>
                <button onclick="nextImage()">下一张</button>
            <?php endif; ?>
        </div>
        <div class="controls">
            <button onclick="startSlideshow()">播放</button>
            <button onclick="stopSlideshow()">暂停</button>
            <button onclick="updatePlaySpeed()">修改播放时长</button>
        </div>
    </div>
</body>
</html>
